plugins/libkolab

Aleksander Machniak machniak at kolabsys.com
Wed Feb 4 11:51:32 CET 2015


 plugins/libkolab/lib/kolab_storage.php |   11 +++++------
 1 file changed, 5 insertions(+), 6 deletions(-)

New commits:
commit 2c9c463e8420f786db1e0dd84cbcc5ae7f553b64
Author: Aleksander Machniak <machniak at kolabsys.com>
Date:   Wed Feb 4 05:41:47 2015 -0500

    Add optional $type argument in kolab_storage::get_folder()

diff --git a/plugins/libkolab/lib/kolab_storage.php b/plugins/libkolab/lib/kolab_storage.php
index 1570b0d..47c1e4b 100644
--- a/plugins/libkolab/lib/kolab_storage.php
+++ b/plugins/libkolab/lib/kolab_storage.php
@@ -144,7 +144,6 @@ class kolab_storage
         return self::$ldap;
     }
 
-
     /**
      * Get a list of storage folders for the given data type
      *
@@ -183,19 +182,19 @@ class kolab_storage
         return null;
     }
 
-
     /**
      * Getter for a specific storage folder
      *
      * @param string  IMAP folder to access (UTF7-IMAP)
      * @return object kolab_storage_folder  The folder object
      */
-    public static function get_folder($folder)
+    public static function get_folder($folder, $type = null)
     {
-        return self::setup() ? new kolab_storage_folder($folder) : null;
+        return self::setup() ? new kolab_storage_folder($folder, $type) : null;
     }
 
-
     /**
      * Getter for a single Kolab object, identified by its UID.
      * This will search all folders storing objects of the given type.
@@ -183,19 +182,19 @@ class kolab_storage
      * Getter for a specific storage folder
      *
-     * @param string  IMAP folder to access (UTF7-IMAP)
+     * @param string IMAP folder to access (UTF7-IMAP)
+     * @param string Expected folder type
+     *
      * @return object kolab_storage_folder  The folder object
      */




More information about the commits mailing list